# dummy key will be used to avoid servers root passwords being mailed
# will use https://authkeys.io to setup real authorization
resource "hcloud_ssh_key" "dummy-key" {
  name       = "dummy-key"
  public_key = "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIDG6KCXcL6bgJKD/ZbzLDeZms6TJwUz7K0yf+KCvfjxV dummy-key"
}

variable "theo_token" {}

resource "hcloud_server" "fcub01" {
  name        = "fcub01"
  image       = "ubuntu-20.04"
  server_type = "cpx31"
  ssh_keys    = [hcloud_ssh_key.dummy-key.id]
  user_data   = templatefile("templates/cloud-init.yml.tpl", { theo_token = var.theo_token })
  lifecycle {
    ignore_changes = [user_data]
  }
}

resource "hcloud_rdns" "fcub01_rdns_ipv4" {
  server_id  = hcloud_server.fcub01.id
  ip_address = hcloud_server.fcub01.ipv4_address
  dns_ptr    = "fcub01.fluidware.it"
}

resource "hcloud_rdns" "fcub01_rdns_ipv6" {
  server_id  = hcloud_server.fcub01.id
  ip_address = hcloud_server.fcub01.ipv6_address
  dns_ptr    = "fcub01.fluidware.it"
}

data "linode_domain" "fluidware-it" {
  domain = "fluidware.it"
}

resource "linode_domain_record" "fcub01-ipv4" {
  domain_id   = data.linode_domain.fluidware-it.id
  name        = "fcub01"
  record_type = "A"
  target      = hcloud_server.fcub01.ipv4_address
}

resource "linode_domain_record" "fcub01-ipv6" {
  domain_id   = data.linode_domain.fluidware-it.id
  name        = "fcub01"
  record_type = "AAAA"
  target      = hcloud_server.fcub01.ipv6_address
}

resource "linode_domain_record" "fcub_fcub" {
  domain_id   = data.linode_domain.fluidware-it.id
  name        = "fcub"
  record_type = "CNAME"
  target      = "fcub01.fluidware.it"
}

resource "linode_domain_record" "grafana_fcub" {
  domain_id   = data.linode_domain.fluidware-it.id
  name        = "grafana.fcub"
  record_type = "CNAME"
  target      = "fcub01.fluidware.it"
}
